pub struct RemoteRoom {Show 13 fields
session: WeakRef<Session>,
uri: OnceCell<MatrixRoomIdUri>,
room_id: RefCell<Option<OwnedRoomId>>,
canonical_alias: RefCell<Option<OwnedRoomAliasId>>,
name: RefCell<Option<String>>,
topic: RefCell<Option<String>>,
topic_linkified: RefCell<Option<String>>,
joined_members_count: Cell<u32>,
can_knock: Cell<bool>,
room_list_info: RoomListRoomInfo,
loading_state: Cell<LoadingState>,
last_request_time: Cell<Option<Instant>>,
request_abort_handle: AbortableHandle,
}Fields
session: WeakRef<Session>The current session.
uri: OnceCell<MatrixRoomIdUri>The Matrix URI of this room.
room_id: RefCell<Option<OwnedRoomId>>The ID of this room.
canonical_alias: RefCell<Option<OwnedRoomAliasId>>The canonical alias of this room.
name: RefCell<Option<String>>The name that is set for this room.
This can be empty, the display name should be used instead in the interface.
topic: RefCell<Option<String>>The topic of this room.
topic_linkified: RefCell<Option<String>>The linkified topic of this room.
This is the string that should be used in the interface when markup is allowed.
joined_members_count: Cell<u32>The number of joined members in the room.
can_knock: Cell<bool>Whether we can knock on the room.
room_list_info: RoomListRoomInfoThe information about this room in the room list.
loading_state: Cell<LoadingState>The loading state.
last_request_time: Cell<Option<Instant>>The time of the last request.
request_abort_handle: AbortableHandleImplementations
Sourceimpl RemoteRoom
impl RemoteRoom
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl RemoteRoom
impl RemoteRoom
Sourcefn set_session(&self, session: &Session)
fn set_session(&self, session: &Session)
Set the current session.
Sourcepub(super) fn set_uri(&self, uri: MatrixRoomIdUri)
pub(super) fn set_uri(&self, uri: MatrixRoomIdUri)
Set the Matrix URI of this room.
Sourcepub(super) fn uri(&self) -> &MatrixRoomIdUri
pub(super) fn uri(&self) -> &MatrixRoomIdUri
The Matrix URI of this room.
Sourcefn set_room_id(&self, room_id: OwnedRoomId)
fn set_room_id(&self, room_id: OwnedRoomId)
Set the ID of this room.
Sourcefn set_canonical_alias(&self, alias: Option<OwnedRoomAliasId>)
fn set_canonical_alias(&self, alias: Option<OwnedRoomAliasId>)
Set the canonical alias of this room.
Sourcepub(super) fn canonical_alias(&self) -> Option<OwnedRoomAliasId>
pub(super) fn canonical_alias(&self) -> Option<OwnedRoomAliasId>
The canonical alias of this room.
Sourcefn update_identifiers(&self)
fn update_identifiers(&self)
Update the identifiers to watch in the room list.
Sourcepub(super) fn update_display_name(&self)
pub(super) fn update_display_name(&self)
The display name of this room.
Sourcefn set_joined_members_count(&self, count: u32)
fn set_joined_members_count(&self, count: u32)
Set the number of joined members in the room.
Sourcefn set_join_rule(&self, join_rule: &JoinRuleSummary)
fn set_join_rule(&self, join_rule: &JoinRuleSummary)
Set the join rule of the room.
Sourcepub(super) fn set_loading_state(&self, loading_state: LoadingState)
pub(super) fn set_loading_state(&self, loading_state: LoadingState)
Set the loading state.
Sourcepub(super) fn is_data_stale(&self) -> bool
pub(super) fn is_data_stale(&self) -> bool
Whether the data of the room is considered to be stale.
Sourcepub(super) fn update_last_request_time(&self)
pub(super) fn update_last_request_time(&self)
Update the last request time to now.
Sourceasync fn load_data_from_summary(&self, session: &Session) -> bool
async fn load_data_from_summary(&self, session: &Session) -> bool
Load the data of this room using the room summary endpoint.
At the time of writing this code, MSC3266 has been accepted but the endpoint is not part of a Matrix spec release.
Returns false if the endpoint is not supported by the homeserver.
Sourceasync fn load_data_from_space_hierarchy(&self, session: &Session)
async fn load_data_from_space_hierarchy(&self, session: &Session)
Load the data of this room using the space hierarchy endpoint.
This endpoint should work for any room already known by the homeserver.